@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2018-2022 Greenbone Networks GmbH
+# Copyright (C) 2018-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -49,7 +49,7 @@ HELP_TEXT = """
       gvm-cli socket --gmp-username foo --gmp-password foo myfile.xml
 
     The protocol specifications for GMP and OSP are available at:
-      https://docs.greenbone.net/index.html#api_documentation"""
+      https://docs.greenbone.net/index.html#api_documentation"""  # noqa: E501
 
 
 def _load_infile(filename=None):
@@ -123,7 +123,6 @@ def main():
 
     try:
         with protocol_class(connection, transform=transform) as protocol:
-
             if args.protocol == PROTOCOL_GMP:
                 # Ask for password if none are given
                 authenticate(protocol, args.gmp_username, args.gmp_password)
