@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2019-2022 Greenbone Networks GmbH
+# Copyright (C) 2019-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -84,7 +84,7 @@ class Config:
         return self._defaults
 
     def get(self, section, name):
-        if not section in self._config:
+        if section not in self._config:
             return None
 
         return self._config[section].get(name)
