@@ -40,7 +40,8 @@ def check_args(args: Namespace) -> None:
         reports via email for selected tasks.
 
         Example for starting up the routine:
-            $ gvm-script --gmp-username name --gmp-password pass ssh --hostname <gsm> scripts/send-delta-emails.gmp.py
+            $ gvm-script --gmp-username name --gmp-password pass ssh \
+                --hostname <gsm> scripts/send-delta-emails.gmp.py
 
         The routine follows this procedure:
 
@@ -82,7 +83,7 @@ def execute_send_delta_emails(sc: sched.scheduler, **kwargs: dict) -> None:
         print(f'Processing task "{task_name}" ({task_id})...')
 
         reports = gmp.get_reports(
-            filter_string="task_id={task_id} and status=Done "
+            filter_string=f"task_id={task_id} and status=Done "
             "sort-reverse=date"
         ).xpath("report")
         print(f"  Found {str(len(reports))} report(s).")
