@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (C) 2019-2022 Greenbone Networks GmbH
+# Copyright (C) 2019-2022 Greenbone AG
 #
 # SPDX-License-Identifier: GPL-3.0-or-later
 #
@@ -112,7 +112,7 @@ class ConfigParserTestCase(unittest.TestCase):
     @patch("gvmtools.parser.Config")
     def test_config_load_raises_error(self, config_mock, path_mock):
         def config_load_error():
-            raise Exception
+            raise Exception  # pylint: disable=broad-exception-raised
 
         config = unittest.mock.MagicMock()
         config.load = unittest.mock.MagicMock(side_effect=config_load_error)
@@ -439,27 +439,35 @@ class HelpFormattingParserTestCase(ParserTestCase):
             path.write_text(output)
             raise
 
+    @unittest.skipIf(
+        sys.version_info[:2] > (3, 10), "missing snapshot for Python 3.11"
+    )
     def test_root_help(self):
-        if self.python_version != "3.10":
-            help_output = self.parser._parser.format_help()
-            self.assert_snapshot("root_help", help_output)
+        help_output = self.parser._parser.format_help()
+        self.assert_snapshot("root_help", help_output)
 
+    @unittest.skipIf(
+        sys.version_info[:2] > (3, 10), "missing snapshot for Python 3.11"
+    )
     def test_socket_help(self):
-        if self.python_version != "3.10":
-            help_output = self.parser._parser_socket.format_help()
-            self.assert_snapshot("socket_help", help_output)
+        help_output = self.parser._parser_socket.format_help()
+        self.assert_snapshot("socket_help", help_output)
 
+    @unittest.skipIf(
+        sys.version_info[:2] > (3, 10), "missing snapshot for Python 3.11"
+    )
     def test_ssh_help(self):
-        if self.python_version != "3.10":
-            self.parser._set_defaults(None)
-            help_output = self.parser._parser_ssh.format_help()
-            self.assert_snapshot("ssh_help", help_output)
+        self.parser._set_defaults(None)
+        help_output = self.parser._parser_ssh.format_help()
+        self.assert_snapshot("ssh_help", help_output)
 
+    @unittest.skipIf(
+        sys.version_info[:2] > (3, 10), "missing snapshot for Python 3.11"
+    )
     def test_tls_help(self):
-        if self.python_version != "3.10":
-            self.parser._set_defaults(None)
-            help_output = self.parser._parser_tls.format_help()
-            self.assert_snapshot("tls_help", help_output)
+        self.parser._set_defaults(None)
+        help_output = self.parser._parser_tls.format_help()
+        self.assert_snapshot("tls_help", help_output)
 
 
 class CreateParserFunctionTestCase(unittest.TestCase):
